@@ -5,6 +5,7 @@
 (defvar coding-category-list nil)
 (defvar current-menubar nil)
 (defvar default-file-name-coding-system nil)
+(defvar default-process-argument-editing-function nil)
 (defvar dnd-protocol-alist nil)
 (defvar elp-function-list nil)
 (defvar elp-results-buffer nil)
@@ -22,6 +23,7 @@
 (defvar mew-summary-toolbar nil)
 (defvar mode-line-position nil)
 (defvar mule-version nil)
+(defvar process-argument-editing-alist nil)
 (defvar profile-buffer nil)
 (defvar profile-functions-list nil)
 (defvar scrollbar-height nil)
@@ -64,9 +66,11 @@
 (defun make-network-process (&rest args))
 (defun make-overlay (&rest args))
 (defun mew-hscroll (&rest args))
+(defun minibuffer-prompt-end (&rest args))
 (defun mouse-set-point (&rest args))
 (defun move-overlay (&rest args))
 (defun multibyte-string-p (&rest args))
+(defun mw32script-argument-editing-function (&rest args))
 (defun mw32script-init (&rest args))
 (defun mw32script-make-pathext-regexp (&rest args))
 (defun mw32script-openp (&rest args))
