@@ -226,11 +226,29 @@ requires PTY.")
     (defalias 'mew-mac-set-file-type 'mac-set-file-type)
   (defmacro mew-mac-set-file-type (&rest args) nil))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Misc
+;;;
+
+(if (fboundp 'fill-match-adaptive-prefix)
+    (defalias 'mew-fill-match-adaptive-prefix 'fill-match-adaptive-prefix)
+  ;; Emacs 21.4
+  (defun mew-fill-match-adaptive-prefix ()
+    (let ((str (or
+		(and adaptive-fill-function (funcall adaptive-fill-function))
+		(and adaptive-fill-regexp (looking-at adaptive-fill-regexp)
+		     (match-string-no-properties 0)))))
+      (if (>= (+ (current-left-margin) (length str)) (current-fill-column))
+	  ;; Death to insanely long prefixes.
+	  nil
+	str))))
+
 (provide 'mew-env)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2008 Mew developing team.
+;; Copyright (C) 1997-2009 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
