@@ -278,7 +278,7 @@ confused. Please use '\\[mew-message-forward]' instead."
 	    width start fill-prefix)
 	(while (not (eobp))
 	  (setq start (point))
-	  (setq fill-prefix (fill-match-adaptive-prefix))
+	  (setq fill-prefix (mew-fill-match-adaptive-prefix))
 	  (end-of-line)
 	  (setq width (current-column))
 	  (forward-line)
@@ -308,7 +308,7 @@ confused. Please use '\\[mew-message-forward]' instead."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2008 Mew developing team.
+;; Copyright (C) 1996-2009 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
