@@ -12,28 +12,20 @@
 ;;; Subfunctions
 ;;;
 
-(defun mew-xemacs-redraw-toolbar ()
-  (when (and mew-icon-p (specifier-instance default-toolbar-visible-p))
-    (set-specifier default-toolbar-visible-p nil)
-    (set-specifier default-toolbar-visible-p t)))
-
 (defmacro mew-summary-prepare-draft (&rest body)
   "Common procedure to prepare a draft."
   `(progn
      (unwind-protect
 	 (let ((inhibit-quit t))
 	   ,@body
-	   ;; XEmacs does not draw attachments unless sit for 0...
 	   (mew-redraw)
-	   (if quit-flag (setq quit-flag nil))
-	   ;; XEmacs does not draw toolbar, so...
-	   (if mew-xemacs-p (mew-xemacs-redraw-toolbar)))
+	   (if quit-flag (setq quit-flag nil)))
        (mew-draft-save-buffer)) ;; to make sure not to use this draft again
      (mew-set-file-modes (buffer-file-name))
      (mew-touch-folder mew-draft-folder)
      (message "Draft is prepared")))
 
-(defsubst mew-summary-prepare-three-windows ()
+(defun mew-summary-prepare-three-windows ()
   "Prepare three windows: Summary mode, Message mode, and Draft mode"
   (unless mew-use-other-frame-for-draft
     (if (get-buffer (mew-buffer-message))
@@ -50,11 +42,10 @@
   (let* ((attach (mew-draft-to-attach draft))
 	 (attachdir (mew-expand-folder attach)))
     (mew-check-directory attachdir)
-    (while files
+    (dolist (file files)
       (if mew-use-symbolic-link-for-forwarding
-	  (mew-symbolic-link (car files) (mew-folder-new-message attach))
-	(copy-file (car files) (mew-folder-new-message attach)))
-      (setq files (cdr files)))))
+	  (mew-symbolic-link file (mew-folder-new-message attach))
+	(copy-file file (mew-folder-new-message attach))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -88,28 +79,34 @@ the current message is copied to To: in a draft."
 	   (message "No message")
 	 (save-excursion
 	   (mew-summary-set-message-buffer fld msg)
-	   (setq to (mew-addrstr-parse-address (mew-header-get-value mew-from:))))
+	   (setq to (mew-addrstr-parse-address (mew-header-get-value mew-from:)))
+	   (if (mew-is-my-address mew-regex-my-address-list to)
+	       (setq to (mew-addrstr-parse-address (mew-header-get-value mew-to:)))))
 	 (mew-summary-send to)
 	 (goto-char (point-min))
 	 (if (search-forward mew-subj: nil t)
 	     (end-of-line)))))))
-  
+
 (defun mew-summary-send (&optional to cc subject newsgroups)
   "Write a message. A new draft is prepared in Draft mode."
   (interactive)
-  (let ((draft (mew-folder-new-message mew-draft-folder)))
-    (if (mew-folder-nntpp (mew-summary-physical-folder))
+  (let ((draft (mew-folder-new-message mew-draft-folder))
+	asked)
+    (if (and (mew-summary-physical-folder)
+	     (mew-folder-nntpp (mew-summary-physical-folder)))
 	(if (null newsgroups) (setq newsgroups ""))
       (when (and mew-ask-to (null to))
-        (setq to (mew-input-address (concat mew-to: " "))))
+        (setq to (mew-input-address (concat mew-to: " ")))
+	(setq asked t))
       (when (and mew-ask-cc (null cc))
-        (setq cc (mew-input-address (concat mew-cc: " ")))))
+        (setq cc (mew-input-address (concat mew-cc: " ")))
+	(setq asked t)))
     (mew-current-set-window-config)
     (mew-window-configure 'draft)
     (mew-summary-prepare-draft
      (mew-draft-find-and-switch draft)
      (mew-delete-directory-recursively (mew-attachdir draft))
-     (mew-draft-header subject nil to cc newsgroups)
+     (mew-draft-header subject nil to cc newsgroups nil nil nil asked)
      (mew-draft-mode)
      (run-hooks 'mew-draft-mode-newdraft-hook))))
 
@@ -118,23 +115,33 @@ the current message is copied to To: in a draft."
 ;;; Replying
 ;;;
 
-(defun mew-subject-simplify (str &optional action-list no-replace)
+(defun mew-subject-simplify (str &optional act-lst no-replace)
   "A function to simplify a value of Subject: according to
 'mew-subject-simplify-replace-alist'."
   (let ((case-fold-search t)
-       regexp replace)
-    (unless action-list (setq action-list mew-subject-simplify-replace-alist))
-    (while action-list
-      (setq regexp  (car (car action-list))
-	    replace (if no-replace nil (cdr (car action-list)))
-	    action-list (cdr action-list))
-      (if (string-match regexp str)
-	  (setq str (replace-match (if replace (eval replace) "") nil t str))))
+	(action-list (or act-lst mew-subject-simplify-replace-alist))
+	(ret str)
+	regexp replace)
+    (dolist (action action-list)
+      (setq regexp (mew-alist-get-key action))
+      (setq replace (if no-replace nil (mew-alist-get-value action)))
+      (if (string-match regexp ret)
+	  (setq ret (replace-match (if replace (eval replace) "") nil t ret))))
+    ret))
+
+(defun mew-subject-simplify-ml (str)
+  (if (string-match "^[[(][^])]+[])][ \t]*" str)
+      (substring str (match-end 0))
     str))
 
+(defun mew-subject-simplify2 (str)
+  (mew-subject-simplify
+   (mew-subject-simplify-ml
+    (mew-subject-simplify str nil 'no-replace)) nil 'no-replace))
+
 (defun mew-to-cc-newsgroups (replysender)
-  (let (alist ent key tcn-flds tcn flds to cc newsgroups fromme func)
-    (cond 
+  (let (alist key tcn flds to cc newsgroups fromme func)
+    (cond
      (replysender
       (setq alist mew-reply-sender-alist)
       (setq func 'mew-header-parse-address-list2))
@@ -148,9 +155,7 @@ the current message is copied to To: in a draft."
       (setq alist mew-reply-all-alist)
       (setq func 'mew-header-parse-address-list2)))
     (catch 'loop
-      (while alist
-	(setq ent (car alist))
-	(setq alist (cdr alist))
+      (dolist (ent alist)
 	(setq key (car ent))
 	(setq ent (cdr ent))
 	(when (or (eq key t)
@@ -158,9 +163,7 @@ the current message is copied to To: in a draft."
 		  (and (listp key)
 		       (string= (mew-header-get-value (nth 0 key))
 				(nth 1 key))))
-	  (while ent
-	    (setq tcn-flds (car ent))
-	    (setq ent (cdr ent))
+	  (dolist (tcn-flds ent)
 	    (setq tcn (car tcn-flds))
 	    (setq flds (cdr tcn-flds))
 	    (cond
@@ -183,7 +186,7 @@ the current message is copied to To: in a draft."
 	id-list in-reply-to references)
     ;; Assuming that In-Reply-To: contains one ID.
     (when old-message-id
-      ;; when old-message-id is nil, 
+      ;; when old-message-id is nil,
       ;; we do not care even if old-references exist.
       (setq in-reply-to old-message-id)
       (cond
@@ -199,7 +202,7 @@ the current message is copied to To: in a draft."
     (list in-reply-to references)))
 
 (defun mew-summary-reply (&optional replysender)
-  "Reply to this message. A new draft is prepared in Draft mode. 
+  "Reply to this message. A new draft is prepared in Draft mode.
 Values of To:, Cc:, and Newsgroups: are prepared according to
 three alists.
 
@@ -209,7 +212,7 @@ three alists.
 \(2) If this message is sent by ME, you probably intend to reply with
     the original header. In this case, 'mew-reply-fromme-alist' is used.
 
-\(3) Otherwise, replying to all people listed. In this case, 
+\(3) Otherwise, replying to all people listed. In this case,
     'mew-reply-all-alist' is used.
 
 The default value of 'mew-reply-sender-alist' is as follows:
@@ -242,7 +245,7 @@ The default value of 'mew-reply-fromme-alist' is as follows:
 
 This is read as follows:
 
-	(2.1) Copying the value of To: to new To: and 
+	(2.1) Copying the value of To: to new To: and
               copying the value of Cc: to new Cc: and
               copying the value of Newsgroups: to new Newsgroups:.
 
@@ -321,7 +324,7 @@ You may want to set 'mew-reply-all-alist' to:
 	   ;; mew-header-* cannot widen essentially. So widen here.
 	   (widen)
 	   ;; now cache buffer
-	   ;; 
+	   ;;
 	   ;; Subject:
 	   (setq subject (mew-header-get-value mew-subj:))
 	   (when subject
@@ -357,7 +360,7 @@ You may want to set 'mew-reply-all-alist' to:
 ;;;
 
 (defun mew-summary-reply-with-citation (&optional replysender)
-  "Answer to this message. A new draft is prepared in Draft mode. 
+  "Answer to this message. A new draft is prepared in Draft mode.
 And this message is automatically cited. See also 'mew-summary-reply'."
   (interactive "P")
   (mew-summary-msg-or-part
@@ -377,14 +380,14 @@ And this message is automatically cited. See also 'mew-summary-reply'."
       (forward-line))
      ((eq mew-summary-reply-with-citation-position 'end)
       (goto-char (point-max)))))))
-  
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Forwarding
 ;;;
 
 (defun mew-summary-forward ()
-  "Forward this message to a third person. A new draft is prepared in 
+  "Forward this message to a third person. A new draft is prepared in
 Draft mode and this message is automatically attached."
   (interactive)
   (mew-summary-msg-or-part
@@ -398,6 +401,7 @@ Draft mode and this message is automatically attached."
 	   (draftdir (file-name-nondirectory draft))
 	   (to (and mew-ask-to (mew-input-address (concat mew-to: " "))))
 	   (cc (and mew-ask-cc (mew-input-address (concat mew-cc: " "))))
+	   (asked (or mew-ask-to mew-ask-cc))
 	   subject fwsubject cwin)
       (mew-summary-prepare-draft
        (mew-summary-prepare-three-windows)
@@ -411,7 +415,7 @@ Draft mode and this message is automatically attached."
 	   (setq fwsubject (mew-subject-simplify (concat mew-forward-string subject))))
        (select-window cwin) ;; draft
        ;;
-       (mew-draft-header fwsubject 'nl to cc)
+       (mew-draft-header fwsubject 'nl to cc nil nil nil nil asked)
        (mew-draft-mode)
        (run-hooks 'mew-draft-mode-newdraft-hook)
        (mew-draft-multi-copy draft (list file))
@@ -425,8 +429,8 @@ Draft mode and this message is automatically attached."
 ;;;
 
 (defun mew-summary-multi-forward ()
-  "Forward messages marked with '*' to a third person. A new draft 
-is prepared in Draft mode and this message is automatically 
+  "Forward messages marked with '*' to a third person. A new draft
+is prepared in Draft mode and this message is automatically
 attached."
   (interactive)
   (mew-summary-multi-msgs
@@ -435,12 +439,13 @@ attached."
     (let* ((draft (mew-folder-new-message mew-draft-folder))
 	   (draftdir (file-name-nondirectory draft))
 	   (to (and mew-ask-to (mew-input-address (concat mew-to: " "))))
-	   (cc (and mew-ask-cc (mew-input-address (concat mew-cc: " ")))))
+	   (cc (and mew-ask-cc (mew-input-address (concat mew-cc: " "))))
+	   (asked (or mew-ask-to mew-ask-cc)))
       (mew-summary-prepare-draft
        (mew-summary-prepare-three-windows)
        (mew-draft-find-and-switch draft t)
        (mew-delete-directory-recursively (mew-attachdir draft))
-       (mew-draft-header nil 'nl to cc)
+       (mew-draft-header nil 'nl to cc nil nil nil nil asked)
        (mew-draft-mode)
        (run-hooks 'mew-draft-mode-newdraft-hook)
        (mew-draft-multi-copy draft FILES)
@@ -453,13 +458,13 @@ attached."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2006 Mew developing team.
+;; Copyright (C) 1996-2009 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -468,7 +473,7 @@ attached."
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
